<?php
/**
 * Default Options.
 *
 * @package news_make
 */

if ( ! function_exists( 'news_make_get_option' ) ) :

	/**
	 * Get theme option.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Option key.
	 * @return mixed Option value.
	 */
	function news_make_get_option( $key ) {

		if ( empty( $key ) ) {
			return;
		}

		$value = '';

		$default = news_make_get_default_theme_options();

		$default_value = null;

		if ( is_array( $default ) && isset( $default[ $key ] ) ) {
			$default_value = $default[ $key ];
		}

		if ( null !== $default_value ) {
			$value = get_theme_mod( $key, $default_value );
		}
		else {
			$value = get_theme_mod( $key );
		}

		return $value;

	}

endif;

if ( ! function_exists( 'news_make_get_default_theme_options' ) ) :

	/**
	 * Get default theme options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
	function news_make_get_default_theme_options() {

		$defaults = array();

		$defaults['news_make_logo_position']			= 'left';
		$defaults['news_make_site_title_font_size']	= 45;

		// Top Header
		$defaults['news_make_ticker_news_title']		= esc_html__('Breaking News','news-make');
		$defaults['news_make_ticker_news_category']	= 0;
		$defaults['news_make_ticker_news_no']			= 10;
		$defaults['news_make_enable_current_date']	= 1;
		$defaults['news_make_enable_search_btn']		= 1;

		// BreadCrumb 
		$defaults['news_make_enable_breadcrumb']		= 1;

		// Footer
		$defaults['news_make_copyright_text']			= esc_html__('copyright text |','news-make');
		$defaults['news_make_enable_scroll_top']		= 1;

		// Featured Posts In Blog Page
		$defaults['news_make_enable_featured_post']	= 0;

		// Theme Sidebar
		$defaults['news_make_sidebar_position']		= 'right';

		// Meta Options
		$defaults['news_make_show_date']				= 1;
		$defaults['news_make_show_author']			= 1;
		$defaults['news_make_show_comments_no']		= 1;
		$defaults['news_make_show_categories']		= 1;

		return $defaults;
	}

endif;
